﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfMultiTouch
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_ManipulationStarting(object sender,
                                             ManipulationStartingEventArgs e)
        {
            e.ManipulationContainer = this;
            e.Handled = true;
        }

        private void Window_ManipulationDelta(object sender,
                                                 ManipulationDeltaEventArgs e)
        {
            Rectangle rect = e.OriginalSource as Rectangle;
            Matrix rectsMatrix = ((MatrixTransform)rect.RenderTransform).Matrix;

            rectsMatrix.RotateAt(e.DeltaManipulation.Rotation,
                                  e.ManipulationOrigin.X, e.ManipulationOrigin.Y);


            rectsMatrix.ScaleAt(e.DeltaManipulation.Scale.X, e.DeltaManipulation.Scale.X,
                                 e.ManipulationOrigin.X, e.ManipulationOrigin.Y);


            rectsMatrix.Translate(e.DeltaManipulation.Translation.X,
                                   e.DeltaManipulation.Translation.Y);

            rect.RenderTransform = new MatrixTransform(rectsMatrix);

            Rect containingRect
                = new Rect(((FrameworkElement)e.ManipulationContainer).RenderSize);
            Rect shapeBounds
                = rect.RenderTransform.TransformBounds(new Rect(rect.RenderSize));
            if (e.IsInertial && !containingRect.Contains(shapeBounds))
            {
                e.Complete();
            }
            e.Handled = true;
        }

        private void Window_ManipulationInertiaStarting(object sender,
                                           ManipulationInertiaStartingEventArgs e)
        {
            //e.TranslationBehavior.DesiredDeceleration = 10.0 * 96.0 / (1000.0 * 1000.0); 
            //e.ExpansionBehavior.DesiredDeceleration = 100.0 * 96 / 1000.0; 
            //e.RotationBehavior.DesiredDeceleration = 720 / (1000.0 * 1000.0);

            e.TranslationBehavior.DesiredDeceleration = 1.0 * 96.0 / (1000.0 * 1000.0);
            e.ExpansionBehavior.DesiredDeceleration = 10.0 * 96 / 1000.0;
            e.RotationBehavior.DesiredDeceleration = 72 / (1000.0 * 1000.0);

            e.Handled = true;
        }
    }
}
